@@ -1,10 +1,9 @@
 # -*- perl -*-
 
 #
-# $Id: Getopt.pm,v 1.65 2008/09/23 19:50:43 eserte Exp $
 # Author: Slaven Rezic
 #
-# Copyright (C) 1997,1998,1999,2000,2003,2007,2008 Slaven Rezic. All rights reserved.
+# Copyright (C) 1997,1998,1999,2000,2003,2007,2008,2012,2014,2017 Slaven Rezic. All rights reserved.
 # This package is free software; you can redistribute it and/or
 # modify it under the same terms as Perl itself.
 #
@@ -26,8 +25,8 @@ use constant OPTEXTRA => 3;
 
 use Carp qw();
 
-$VERSION = '0.50';
-$VERSION = eval $VERSION;
+$VERSION = '0.51';
+$VERSION =~ s{_}{};
 
 $DEBUG = 0;
 $x11_pass_through = 0;
@@ -208,6 +207,15 @@ sub load_options {
     my($self, $filename) = @_;
     $filename = $self->{'filename'} if !$filename;
     return if !$filename;
+    require File::Spec;
+    if (!-e $filename) {
+	warn "File $filename does not exist";
+	return undef;
+    }
+    if (!File::Spec->file_name_is_absolute($filename)) {
+	# required for do operation with PERL_USE_UNSAFE_INC=0
+	$filename = File::Spec->rel2abs($filename);
+    }
     if ($self->{'nosafe'}) {
 	require Safe;
 	my $c = new Safe;
@@ -777,7 +785,7 @@ sub _filedialog_widget {
 		   $file = $topframe->$fd(-title => 'Select file');
 	       } elsif ($fd eq '_dir_select') {
 		   require Cwd;
-		   $file = _dir_select($topframe, Cwd::cwd());
+		   $file = _dir_select($topframe, Cwd::getcwd());
 	       } else {
 		   if ($subtype eq 'dir') {
 		       $file = $filedialog->Show(-verify => [qw(-d)]);
